camelot.camelot.view.proxy.collection_proxy.DelayedProxy

Package camelot :: Package camelot :: Package view :: Package proxy :: Module collection_proxy :: Class DelayedProxy |
[hide private]
[frames] | no frames]

# Class DelayedProxy

source code

A proxy object needs to be constructed within the GUI thread. Construct a delayed proxy when the construction of a proxy is needed within the Model thread. On first occasion the delayed proxy will be converted to a real proxy within the GUI thread

Instance Methods | [hide private]
__init__(self, *args, **kwargs) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__call__(self) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, *args, **kwargs) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Decorators: `@model_function` Overrides: object.__init__ (inherited documentation)

### __call__(self) (Call operator) | source code
Decorators: `@gui_function`